@@ -1,4 +1,5 @@
 import json
+
 from django import http
 
 
@@ -7,14 +8,16 @@ def to_json(request, data):
         response = json.dumps(data, indent=4)
         try:
             from pygments import highlight, lexers, formatters
-            return http.HttpResponse(highlight(
-                response,
-                lexers.get_lexer_by_name('json'),
-                formatters.get_formatter_by_name('html', full=True),
-            ))
+            return http.HttpResponse(
+                highlight(
+                    response,
+                    lexers.get_lexer_by_name('json'),
+                    formatters.get_formatter_by_name('html', full=True),
+                )
+            )
         except ImportError:
             return http.HttpResponse(response, content_type='text/plain')
     else:
         return http.HttpResponse(
-            json.dumps(data), content_type='application/json')
-
+            json.dumps(data), content_type='application/json'
+        )
